@@ -1500,7 +1500,7 @@ def _split_even_to_part(partition_book, elements):
     x = y = 0
     num_elements = len(elements)
     block_size = num_elements // partition_book.num_partitions()
-    part_eles = None
+    part_eles = F.tensor([], dtype=elements.dtype)
     # compute the nonzero tensor of each partition instead of whole tensor to save memory
     for idx in range(0, num_elements, block_size):
         nonzero_block = F.nonzero_1d(
@@ -1512,10 +1512,7 @@ def _split_even_to_part(partition_book, elements):
             start = max(x, left) - x
             end = min(y, right) - x
             tmp = nonzero_block[start:end] + idx
-            if part_eles is None:
-                part_eles = tmp
-            else:
-                part_eles = F.cat((part_eles, tmp), 0)
+            part_eles = F.cat((part_eles, tmp), 0)
         elif x >= right:
             break
 
